asr.core.cli
============

.. automodule:: asr.core.cli

   
   
   .. rubric:: Functions

   
   .. autofunction:: check_git
   .. autofunction:: extract_hash_from_file
   .. autofunction:: format
   .. autofunction:: get_config_dir
   .. autofunction:: get_git_rev_list
   .. autofunction:: initialize_asr_configuration_dir
   .. autofunction:: is_asr_initialized
   
   

   
   
   

   
   
   